# About Linpg Engine

###### *"Just because c++ is the greatest language ever invented doesn't mean that writing games in c++ is easy and fun, and the same goes for pygame."*

Linpg Engine is a game engine independently developed by Tigeia Workshop based on the pygame library, which aims to standardize the development of pygame games, as well as to make the codes easier to read, expand and maintain.

Linpg Engine is developed with a modular concept. It implements many features commonly used in game development. Simultaneously, the Linpg Engine also maintains a high level of compatibility with pygame, making it easy for developers to migrate existing pygame projects to Linpg Engine or use Linpg Engine features on their pygame projects.

We always need your help to make Linpg the best it can be! No matter what your region, culture, belief, or age is, any contributors are welcome!

More information about Linpg Engine can be found here: https://github.com/Tigeia-Workshop/linpg

